@@ -1,4 +1,7 @@
 from dataclasses import dataclass, field
+import pathlib
+
+dir = pathlib.Path(__file__).parent.parent.resolve()
 
 @dataclass
 class ClusterConfiguration:
@@ -12,8 +15,7 @@ class ClusterConfiguration:
     min_memory: int = 2
     max_memory: int = 2
     gpu: int = 0
-    template: str = "src/codeflare_sdk/templates/new-template.yaml"
+    template: str = f"{dir}/templates/new-template.yaml"
     instascale: bool = False
     envs: dict = field(default_factory=dict)
     image: str = "ghcr.io/ibm-ai-foundation/base:ray1.13.0-py38-gpu-pytorch1.12.0cu116-20220826-202124"
-
